@@ -14,6 +14,7 @@
 
 pub mod cliutil;
 pub mod dateutil;
+pub mod fileutil;
 pub mod logutil;
 pub mod util;
 
@@ -29,10 +30,10 @@ macro_rules! open_source_shim {
         #[cfg(fbcode_build)]
         mod facebook;
         #[cfg(fbcode_build)]
-        use crate::facebook::*;
+        use facebook::*;
         #[cfg(not(fbcode_build))]
         mod open_source;
         #[cfg(not(fbcode_build))]
-        use crate::open_source::*;
+        use open_source::*;
     };
 }
